@@ -68,9 +68,9 @@ import Data.Maybe
 import Control.Applicative (Applicative(..))
 import Control.Monad (liftM, ap)
 import Control.Monad.Identity
-import Control.Monad.State.Class
+import Control.Monad.State.Class (MonadState, get, put, modify, gets)
 import Control.Monad.Trans
-import Prelude hiding (lookup)
+import Prelude hiding (Applicative(..), lookup)
 
 class (Monad m) => MonadName m where
     -- | unique name generation
@@ -419,11 +419,10 @@ instance Monad f => Functor (TravT s f) where
     fmap = liftM
 
 instance Monad f => Applicative (TravT s f) where
-    pure  = return
+    pure x  = TravT (\s -> return (Right (x,s)))
     (<*>) = ap
 
 instance Monad m => Monad (TravT s m) where
-    return x  = TravT (\s -> return (Right (x,s)))
     m >>= k   = TravT (\s -> unTravT m s >>= \y -> case y of
                               Right (x,s1) -> unTravT (k x) s1
                               Left e       -> return (Left e))
