@@ -204,7 +204,7 @@ instance Pretty CDecl where
                 attrlistP (getAttrs declr) <+>
                 maybeP ((text "=" <+>) . pretty) initializer
             checked_specs =
-                if any isAttrAfterSUE  (zip specs (tail specs))
+                if any isAttrAfterSUE  (zip specs (drop 1 specs))
                     then trace
                            ("Warning: AST Invariant violated: __attribute__ specifier following struct/union/enum:" ++
                             show (map pretty specs))
@@ -473,6 +473,9 @@ instance Pretty CBuiltin where
     pretty (CBuiltinConvertVector expr ty _)  =
         text "__builtin_convertvector" <+>
         parens (pretty expr <> comma <+> pretty ty)
+    pretty (CBuiltinBitCast ty expr _)  =
+        text "__builtin_bit_cast" <+>
+        parens (pretty ty <> comma <+> pretty expr)
 
 instance Pretty CAssignOp where
   pretty op = text $ case op of
