@@ -468,6 +468,7 @@ data CTypeSpecifier a
   | CBoolType    a
   | CComplexType a
   | CInt128Type  a
+  | CUInt128Type a
   | CFloatNType Int Bool a           -- ^ IEC 60227: width (32,64,128), extended flag
   | CSUType      (CStructureUnion a) a      -- ^ Struct or Union specifier
   | CEnumType    (CEnumeration a)    a      -- ^ Enumeration specifier
@@ -762,6 +763,7 @@ data CBuiltinThing a
   | CBuiltinOffsetOf (CDeclaration a) [CPartDesignator a] a -- ^ @(type, designator-list)@
   | CBuiltinTypesCompatible (CDeclaration a) (CDeclaration a) a  -- ^ @(type,type)@
   | CBuiltinConvertVector (CExpression a) (CDeclaration a) a -- ^ @(expr, type)@
+  | CBuiltinBitCast (CDeclaration a) (CExpression a) a -- ^ @(type, expr)@
     deriving (Show, Data,Typeable, Generic {-! ,CNode ,Functor ,Annotated !-})
 
 instance NFData a => NFData (CBuiltinThing a)
@@ -1096,6 +1098,7 @@ instance CNode t1 => CNode (CTypeSpecifier t1) where
         nodeInfo (CBoolType d) = nodeInfo d
         nodeInfo (CComplexType d) = nodeInfo d
         nodeInfo (CInt128Type d) = nodeInfo d
+        nodeInfo (CUInt128Type d) = nodeInfo d
         nodeInfo (CSUType _ n) = nodeInfo n
         nodeInfo (CEnumType _ n) = nodeInfo n
         nodeInfo (CTypeDef _ n) = nodeInfo n
@@ -1119,6 +1122,7 @@ instance Functor CTypeSpecifier where
         fmap _f (CBoolType a1) = CBoolType (_f a1)
         fmap _f (CComplexType a1) = CComplexType (_f a1)
         fmap _f (CInt128Type a1) = CInt128Type (_f a1)
+        fmap _f (CUInt128Type a1) = CUInt128Type (_f a1)
         fmap _f (CSUType a1 a2) = CSUType (fmap _f a1) (_f a2)
         fmap _f (CEnumType a1 a2) = CEnumType (fmap _f a1) (_f a2)
         fmap _f (CTypeDef a1 a2) = CTypeDef a1 (_f a2)
@@ -1140,6 +1144,7 @@ instance Annotated CTypeSpecifier where
         annotation (CBoolType n) = n
         annotation (CComplexType n) = n
         annotation (CInt128Type n) = n
+        annotation (CUInt128Type n) = n
         annotation (CSUType _ n) = n
         annotation (CEnumType _ n) = n
         annotation (CTypeDef _ n) = n
@@ -1159,6 +1164,7 @@ instance Annotated CTypeSpecifier where
         amap f (CBoolType a_1) = CBoolType (f a_1)
         amap f (CComplexType a_1) = CComplexType (f a_1)
         amap f (CInt128Type a_1) = CInt128Type (f a_1)
+        amap f (CUInt128Type a_1) = CUInt128Type (f a_1)
         amap f (CSUType a_1 a_2) = CSUType a_1 (f a_2)
         amap f (CEnumType a_1 a_2) = CEnumType a_1 (f a_2)
         amap f (CTypeDef a_1 a_2) = CTypeDef a_1 (f a_2)
@@ -1396,6 +1402,7 @@ instance CNode t1 => CNode (CBuiltinThing t1) where
         nodeInfo (CBuiltinOffsetOf _ _ n) = nodeInfo n
         nodeInfo (CBuiltinTypesCompatible _ _ n) = nodeInfo n
         nodeInfo (CBuiltinConvertVector _ _ n) = nodeInfo n
+        nodeInfo (CBuiltinBitCast _ _ n) = nodeInfo n
 instance CNode t1 => Pos (CBuiltinThing t1) where
         posOf x = posOf (nodeInfo x)
 
@@ -1408,12 +1415,15 @@ instance Functor CBuiltinThing where
           = CBuiltinTypesCompatible (fmap _f a1) (fmap _f a2) (_f a3)
         fmap _f (CBuiltinConvertVector a1 a2 a3)
           = CBuiltinConvertVector (fmap _f a1) (fmap _f a2) (_f a3)
+        fmap _f (CBuiltinBitCast a1 a2 a3)
+          = CBuiltinBitCast (fmap _f a1) (fmap _f a2) (_f a3)
 
 instance Annotated CBuiltinThing where
         annotation (CBuiltinVaArg _ _ n) = n
         annotation (CBuiltinOffsetOf _ _ n) = n
         annotation (CBuiltinTypesCompatible _ _ n) = n
         annotation (CBuiltinConvertVector _ _ n) = n
+        annotation (CBuiltinBitCast _ _ n) = n
         amap f (CBuiltinVaArg a_1 a_2 a_3) = CBuiltinVaArg a_1 a_2 (f a_3)
         amap f (CBuiltinOffsetOf a_1 a_2 a_3)
           = CBuiltinOffsetOf a_1 a_2 (f a_3)
@@ -1421,6 +1431,8 @@ instance Annotated CBuiltinThing where
           = CBuiltinTypesCompatible a_1 a_2 (f a_3)
         amap f (CBuiltinConvertVector a_1 a_2 a_3) =
           CBuiltinConvertVector a_1 a_2 (f a_3)
+        amap f (CBuiltinBitCast a_1 a_2 a_3) =
+          CBuiltinBitCast a_1 a_2 (f a_3)
 
 instance CNode t1 => CNode (CConstant t1) where
         nodeInfo (CIntConst _ n) = nodeInfo n
